@@ -7,20 +7,21 @@
 #include "modules.h"
 #include "kadu.h"
 #include "userlist.h"
-#include "chat.h"
-#include "history.h"
+//#include "chat.h"
+#include "modules/history/history.h"
 #include "search.h"
 #include "pending_msgs.h"
-#include "config_dialog.h"
+// #include "config_dialog.h"
 #include "modules/notify/notify.h"
 #include "modules/sms/sms.h"
 #include "modules/sms/sms.h"
-#include "modules/dcc/file_transfer.h"
+#include "modules/dcc/file_transfer_manager.h"
 #include "debug.h"
 #include "message_box.h"
 #include "groups_manager.h"
 #include "pending_msgs.h"
 #include "chat_manager.h"
+#include "protocols_manager.h"
 
 #include "DCOPExport.h"
 
@@ -51,7 +52,7 @@ DCOPExport::DCOPExport ():
 	bool qtdcopbridge = config_file.readBoolEntry ("dcopexport", "qt-dcop-bridge", true);
 	bool acceptCalls = config_file.readBoolEntry ("dcopexport", "accept-calls", true);
 
-	ConfigDialog::addTab ("dcopexport", dataPath ("kadu/modules/data/dcopexport/dcopexport.png"));
+/*	ConfigDialog::addTab ("dcopexport", dataPath ("kadu/modules/data/dcopexport/dcopexport.png"));
 	ConfigDialog::addCheckBox (
 		"dcopexport",
 		"dcopexport",
@@ -133,7 +134,7 @@ DCOPExport::DCOPExport ():
 		QT_TRANSLATE_NOOP("@default", "Allow writing secret data (like passwords etc)")
 	);
 	ConfigDialog::registerSlotOnApplyTab ("dcopexport", this, SLOT(applyConfig()));
-
+*/
 	DCOPClient *dcopcl = KApplication::dcopClient ();
 	if (dcopcl) {
 		connect (dcopcl,
@@ -163,7 +164,7 @@ DCOPExport::~DCOPExport ()
 		);
 	}
 		
-	ConfigDialog::unregisterSlotOnApplyTab ("dcopexport", this, SLOT(applyConfig()));
+/*	ConfigDialog::unregisterSlotOnApplyTab ("dcopexport", this, SLOT(applyConfig()));
 
 	ConfigDialog::removeControl ("dcopexport", "Enable Qt-DCOP bridge");
 	ConfigDialog::removeControl ("dcopexport", "Accept DCOP calls");
@@ -174,7 +175,7 @@ DCOPExport::~DCOPExport ()
 	ConfigDialog::removeControl ("dcopexport", "Allow to write secret data");
 	ConfigDialog::removeControl ("dcopexport", "Install description change from Konqueror");
 	ConfigDialog::removeTab ("dcopexport");
-
+*/
 	if (installGGProcess) {
 		delete installGGProcess;
 	}
@@ -298,7 +299,7 @@ void DCOPExport::installGGProcessExited()
 		info += installGGProcess->readStdout ();
 		info += installGGProcess->readStderr ();
 		
-		MessageBox::wrn (tr("Installation not succesfull:\n") + info);
+		MessageBox::msg (tr("Installation not succesfull:\n") + info);
 	}
 	disconnect (installGGProcess, SIGNAL(processExited()), this, SLOT(installGGProcessExited()));
 }
@@ -317,7 +318,7 @@ void DCOPExport::cleanupForKadu ()
 			if (dcopcl->detach ()) {
 				kdebugm (KDEBUG_INFO, "kadu detached\n");
 			} else {
-				kdebugm (KDEBUG_INFO, "kadu not detached (??)\n");
+				kdebugm (KDEBUG_INFO, "kadu not detached (?)\n");
 			}
 		} else {
 			kdebugm (KDEBUG_INFO, "kadu not registered, not detaching\n");
@@ -339,9 +340,10 @@ void DCOPExport::sendMessage (const QString &uin, const QString &message)
 	recv.append (userlist->byID ("Gadu", uin));
 
 	if (! gadu->currentStatus().isOffline ()) {
-		if (gadu->sendMessage (recv, unicode2cp (message)) == -1) {
+		gadu->sendMessage (recv, unicode2cp (message));
+		/*if (gadu->sendMessage (recv, unicode2cp (message)) == -1) {
 			kdebugm (KDEBUG_WARNING, "couldn't send message\n");
-		}
+		}*/
 	}
 }
 
@@ -355,13 +357,17 @@ void DCOPExport::sendMessageWithHistory (const QString &uin, const QString &mess
 	recv.append (userlist->byID ("Gadu", uin));
 
 	if (! gadu->currentStatus().isOffline ()) {
-		if (gadu->sendMessage (recv, unicode2cp (message)) == -1) {
+		gadu->sendMessage (recv, unicode2cp (message));
+		UinsList recver;
+		recver.append (uin.toUInt ());
+		history->addMyMessage (recver, message);
+		/*if (gadu->sendMessage (recv, unicode2cp (message)) == -1) {
 			kdebugm (KDEBUG_WARNING, "couldn't send message\n");
 		} else {
 			UinsList recver;
 			recver.append (uin.toUInt ()); //config_file.readNumEntry ("General", "UIN"));
 			history->addMyMessage (recver, message);
-		}
+		}*/
 	}
 }
 
@@ -420,10 +426,6 @@ QStringList DCOPExport::getUserInfo (QString uin)
 	
 	QStringList userInfo;
 	
-#if 0
-	if (userlist.containsUin (UinsList(uin)[0])) {
-		UserListElement ule = userlist.byUin (UinsList(uin)[0]);
-#endif
 	if (userlist->contains ("Gadu", uin)) {
 		UserListElement ule = userlist->byID ("Gadu", uin);
 		userInfo << QString("Uin: %1").arg (uin);
@@ -433,15 +435,8 @@ QStringList DCOPExport::getUserInfo (QString uin)
 		userInfo << QString("LastName: %1").arg (ule.lastName ());
 		userInfo << QString("Mobile: %1").arg (ule.mobile ());
 		userInfo << QString("Email: %1").arg (ule.email ());
-#if 0
-		userInfo << QString("Status: %1").arg (ule.status ().index ());
-		userInfo << QString("Desc: %1").arg (ule.status ().description ());
-#endif
 		userInfo << QString("Status: %1").arg (ule.status ("Gadu").index ());
 		userInfo << QString("Desc: %1").arg (ule.status ("Gadu").description ());
-#if 0
-		userInfo << QString("IP: %1:%2").arg (ule.ip ().toString ()).arg (ule.port ());
-#endif
 		userInfo << QString("IP: %1:%2").arg (ule.IP ("Gadu").toString ()).arg (ule.port ("Gadu"));
 	}
 	
@@ -456,7 +451,14 @@ QString DCOPExport::description ()
 
 void DCOPExport::setDescription (QString desc)
 {
-	gadu->status ().setDescription (desc);
+	if (isOffline ())
+		kadu->setOffline (desc);
+	else if (isInvisible ())
+		kadu->setInvisible (desc);
+	else if (isBusy ())
+		kadu->setBusy (desc);
+	else if (isOnline ())
+		kadu->setOnline (desc);
 }
 
 void DCOPExport::setOnline ()
@@ -466,7 +468,7 @@ void DCOPExport::setOnline ()
 
 void DCOPExport::setOnline (const QString& desc)
 {
-	gadu->status ().setOnline (desc);
+	kadu->setOnline (desc);
 }
 
 bool DCOPExport::isOnline ()
@@ -481,7 +483,7 @@ void DCOPExport::setBusy ()
 
 void DCOPExport::setBusy (const QString& desc)
 {
-	gadu->status ().setBusy (desc);
+	kadu->setBusy (desc);
 }
 
 bool DCOPExport::isBusy ()
@@ -496,7 +498,7 @@ void DCOPExport::setInvisible ()
 
 void DCOPExport::setInvisible (const QString& desc)
 {
-	gadu->status ().setInvisible (desc);
+	kadu->setInvisible (desc);
 }
 
 bool DCOPExport::isInvisible ()
@@ -511,7 +513,7 @@ void DCOPExport::setOffline ()
 
 void DCOPExport::setOffline (const QString& desc)
 {
-	gadu->status ().setOffline (desc);
+	kadu->setOffline (desc);
 }
 
 bool DCOPExport::isOffline ()
@@ -521,7 +523,8 @@ bool DCOPExport::isOffline ()
 
 void DCOPExport::setFriendsOnly (bool b)
 {
-	gadu->status ().setFriendsOnly (b);
+	// bylo dobrze ale ktos zepsul, to ja poczekam az naprawi
+	// gadu->status ().setFriendsOnly (b);
 }
 
 bool DCOPExport::isFriendsOnly ()
@@ -546,7 +549,11 @@ void DCOPExport::openChat(QString uins)
 	if (pending.pendingMsgs (ul[0])) {
 		chat_manager->openPendingMsgs (ul);
 	} else {
-		chat_manager->openChat ("Gadu", ul);
+		Protocol *protocol = protocols_manager->byID ("Gadu", QString::number (config_file.readNumEntry ("General", "UIN")));
+		if (protocol)
+			chat_manager->openChatWidget (protocol, ul);
+		else
+			kdebugm(KDEBUG_WARNING, "protocol Gadu/%s not found!\n", QString::number (config_file.readNumEntry ("General", "UIN")).local8Bit().data());
 	}
 }
 
@@ -557,7 +564,21 @@ void DCOPExport::openSearchDialog (QString uin)
 
 void DCOPExport::showHistory (QString uins)
 {
-	(new History(UinsList (uins)))->show();
+	// BYLO:
+	// (new History(UinsList (uins)))->show();
+	QStringList ulist = QStringList::split (",", uins);
+	UserListElements ul;
+	for (
+		QStringList::const_iterator slci = ulist.begin ();
+		slci != ulist.end ();
+		++ slci
+	) {
+		ul.append (userlist->byID ("Gadu", *slci));
+	}
+
+	UserGroup user_group(ul);
+	KaduActions["showHistoryAction"]->activate(&user_group);
+	
 }
 
 void DCOPExport::openUrl (const QString& url)
@@ -630,12 +651,14 @@ QString DCOPExport::passwordHash (const QString &s)
 
 void DCOPExport::showMessage (QString type, QString text)
 {
-	notify->emitMessage("DCOP", type, text);
+	Notification *n = new Notification(type, "", UserListElements());
+	n->setText (text);
+	notification_manager->notify (n);
 }
 
 QStringList DCOPExport::getMessageTypes ()
 {
-	return notify->notifiersList();
+	return notification_manager->notifiersList();
 }
 
 void DCOPExport::sendFile (const QString &uin, const QString &path)
@@ -681,7 +704,7 @@ bool DCOPExport::sendUserSMS (const QString &sender, const QString &altnick, con
 	if (userlist->containsAltNick (altnick)) {
 		number = userlist->byAltNick (altnick).mobile ();
 		
-		if ((smsgateway = smsslots->getGateway (number)) != 0) {
+		if ((smsgateway = smsConfigurationUiHandler->getGateway (number)) != 0) {
 				smsgateway->send (number, message, QString::null, sender);
 		} else {
 			retval = false;
@@ -702,7 +725,7 @@ bool DCOPExport::sendSMS (const QString &sender, const QString &number, const QS
 	bool retval = true;
 	SmsGateway *smsgateway;
 	
-	if ((smsgateway = smsslots->getGateway (number)) != 0) {
+	if ((smsgateway = smsConfigurationUiHandler->getGateway (number)) != 0) {
 			smsgateway->send (number, message, QString::null, sender);
 	} else {
 		retval = false;
