@@ -227,7 +227,12 @@ void Filtering::on_textLE_returnPressed ()
 
 void Filtering::createDefaultConfiguration()
 {
-	// LOL
+	config_file.addVariable("filtering", "filter-startonany", true);
+	config_file.addVariable("filtering", "filter-showonload", false);
+	config_file.addVariable("filtering", "filter-number", true);
+	config_file.addVariable("filtering", "filter-email", true);
+	config_file.addVariable("filtering", "filter-mobile", true);
+	config_file.addVariable("filtering", "filter-startswith", false);
 	config_file.addVariable("ShortCuts", "filtering_start", "/");
 }
 
