@@ -229,12 +229,15 @@ ChatManager::~ChatManager()
 	kdebugf2();
 }
 
-void ChatManager::autoSendActionActivated(const UserGroup* users, const QWidget* /*source*/, bool is_on)
+void ChatManager::autoSendActionActivated(const UserGroup* /*users*/, const QWidget* /*source*/, bool is_on)
 {
 	kdebugf();
-	findChatWidget(users)->setAutoSend(is_on);
+
+	CONST_FOREACH(chat, ChatWidgets)
+		(*chat)->setAutoSend(is_on);
 	KaduActions["autoSendAction"]->setAllOn(is_on);
 	config_file.writeEntry("Chat", "AutoSend", is_on);
+
 	kdebugf2();
 }
 
@@ -339,7 +342,11 @@ void ChatManager::ignoreUserActionActivated(const UserGroup* users)
 				IgnoredManager::insert(u);
 				ChatWidget *chat = findChatWidget(u);
 				if (chat)
-					static_cast<QWidget *>(chat->parent())->close();
+				{
+					ChatContainer * container = dynamic_cast<ChatContainer *>(chat->topLevelWidget());
+					if (container)
+						container->closeChatWidget(chat);
+				}
 			}
 			kadu->userbox()->refresh();
 			IgnoredManager::writeToConfiguration();
@@ -383,7 +390,11 @@ void ChatManager::blockUserActionActivated(const UserGroup *users)
 
 			ChatWidget *chat = findChatWidget(users->toUserListElements());
 			if (chat)
-				static_cast<QWidget *>(chat->parent())->close();
+			{
+				ChatContainer * container = dynamic_cast<ChatContainer *>(chat->topLevelWidget());
+				if (container)
+					container->closeChatWidget(chat);
+			}
 		}
 
 		userlist->writeToConfig();
@@ -532,7 +543,7 @@ int ChatManager::openChatWidget(Protocol *initialProtocol, const UserListElement
 			}
 #if QT_VERSION >= 0x030300
 			if (qstrcmp(qVersion(), "3.3") >= 0) // dodatkowe zabezpieczenie przed idiotami uywajcymi opcji --force przy instalacji pakietw
-				win->setWindowState(win->windowState() & ~WindowMinimized | WindowActive);
+				win->setWindowState(win->windowState() & (~WindowMinimized | WindowActive));
 #endif
 			if (forceActivate)
 				activateWindow(win->winId());
@@ -551,14 +562,6 @@ int ChatManager::openChatWidget(Protocol *initialProtocol, const UserListElement
 
 	ChatWidget *chat = new ChatWidget(initialProtocol, users);
 
-	if (forceActivate)
-	{
-		QWidget *win = chat;
-		while (win->parent())
-			win = static_cast<QWidget *>(win->parent());
-		activateWindow(win->winId());
-	}
-
 	bool handled = false;
 	emit handleNewChatWidget(chat, handled);
 	if (!handled)
@@ -573,6 +576,14 @@ int ChatManager::openChatWidget(Protocol *initialProtocol, const UserListElement
 	connect(chat, SIGNAL(messageSentAndConfirmed(UserListElements, const QString&)),
 		this, SIGNAL(messageSentAndConfirmed(UserListElements, const QString&)));
 
+	if (forceActivate)
+	{
+		QWidget *win = chat;
+		while (win->parent())
+			win = static_cast<QWidget *>(win->parent());
+		activateWindow(win->winId());
+	}
+
 //	chat->makeActive();
 	emit chatWidgetCreated(chat);
 // TODO: remove, it is so stupid ...
@@ -617,6 +628,8 @@ void ChatManager::openPendingMsgs(UserListElements users, bool forceActivate)
 	QValueList<ChatMessage *> messages;
 	PendingMsgs::Element elem;
 
+	int chat = openChatWidget(gadu, users, forceActivate);
+
 	for (int i = 0; i < pending.count(); ++i)
 	{
 		elem = pending[i];
@@ -633,13 +646,10 @@ void ChatManager::openPendingMsgs(UserListElements users, bool forceActivate)
 	if (messages.size())
 	{
 		// TODO: Lame API
-		int i = openChatWidget(gadu, users, forceActivate);
-		if (ChatWidgets[i]->countMessages() == 0)
-			ChatWidgets[i]->appendMessages(messages);
+		if (!ChatWidgets[chat]->countMessages())
+			ChatWidgets[chat]->appendMessages(messages, true);
 		UserBox::refreshAllLater();
 	}
-	else
-		openChatWidget(gadu, users, forceActivate);
 
 	kdebugf2();
 }
