@@ -205,6 +205,8 @@ SearchDialog::SearchDialog(QWidget *parent, const char *name, UinType whoisSearc
 
 	connect(gadu, SIGNAL(newSearchResults(SearchResults &, int, int)), this, SLOT(newSearchResults(SearchResults &, int, int)));
 
+	connect(kadu, SIGNAL(statusPixmapChanged(const QPixmap &, const QString &)), this, SLOT(refreshIcon(const QPixmap &)));
+
 	kdebugf2();
 }
 
@@ -358,6 +360,9 @@ void SearchDialog::firstSearch(void)
 	if (results->childCount())
 		clearResults();
 
+	if (searching)
+		gadu->stopSearchInPubdir(*searchRecord);
+
 	searchRecord->clearData();
 
 	if (r_pers->isChecked())
@@ -428,14 +433,16 @@ void SearchDialog::newSearchResults(SearchResults& searchResults, int seq, int f
 {
 	kdebugf();
 
-	QListViewItem *qlv = NULL;
-	QPixmap pix;
-
 	if ((seq != searchRecord->Seq) || searchRecord->IgnoreResults)
 		return;
 
+	QListViewItem *qlv = NULL;
+	QPixmap pix;
+
 	searchRecord->FromUin = fromUin;
 
+	int items = results->childCount(); // number of items already in results
+
 	// ??	if ((status && atoi(status) <= 1 && only_active->isChecked()) || !status)
 
 	CONST_FOREACH(searchIterator, searchResults)
@@ -484,7 +491,7 @@ void SearchDialog::newSearchResults(SearchResults& searchResults, int seq, int f
 		first_search_action->setEnabled(this, true);
 	stop_search_action->setEnabled(this, false);
 
-	if (searchResults.isEmpty())
+	if (searchResults.isEmpty() || ((int)searchResults.count() == items))
 	{
 		kdebugmf(KDEBUG_INFO, "No results. Exit.\n");
 		MessageBox::msg(tr("There were no results of your search"), false, "Information", this);
@@ -494,7 +501,10 @@ void SearchDialog::newSearchResults(SearchResults& searchResults, int seq, int f
 	{
 		if (r_pers->isChecked() && !isPersonalDataEmpty())
 			next_results_action->setEnabled(this, true);
+	}
 
+	if (results->selectedItem())
+	{
 		clear_search_action->setEnabled(this, true);
 		add_searched_action->setEnabled(this, true);
 		chat_searched_action->setEnabled(this, true);
@@ -672,3 +682,8 @@ void SearchDialog::selectionChanged()
 	add_searched_action->setEnabled(this, enableActions);
 	chat_searched_action->setEnabled(this, enableActions);
 }
+
+void SearchDialog::refreshIcon(const QPixmap &pix)
+{
+	setIcon(pix);
+}
