@@ -31,6 +31,7 @@ rozteck <at> interia.pl
 #include <qcombobox.h>
 #include <qspinbox.h>
 #include <qpixmap.h>
+#include <qcursor.h>
 
 #include "icons_manager.h"
 #include "osd_manager.h"
@@ -76,16 +77,14 @@ void OSDManager::chatCreated(ChatWidget *widget)
 	kdebugf();
 
 	const UserGroup *group = widget->users();
-	
-	FOREACH(i, *group)
+
+	FOREACH(j, widgets)
 	{
-		FOREACH(j, widgets)
+		if ((*j) && (*j)->hasUsers() && group->equals((*j)->getUsers()))
 		{
-			if ((*j)->getUsers().contains(*i))
-			{
-				timeout((*j)->getID(), true);
-				break;
-			}
+			kdebugm(KDEBUG_INFO, "first widget to remove: %d\n", (*j)->getID());
+			timeout((*j)->getID(), group);
+			break;
 		}
 	}
 
@@ -114,7 +113,7 @@ void OSDManager::addOSD(Notification *notification)
 {
 	kdebugf();
 	// TODO: co sie da przeniesc stad do konstruktora OSDWidget
-kdebugm(KDEBUG_ERROR, "\n\n\n\n\n\naddOSD\n");
+
 	if (new_osd == 4)
 		deleteAllWidgets();
 
@@ -155,9 +154,21 @@ kdebugm(KDEBUG_ERROR, "\n\n\n\n\n\naddOSD\n");
 		ule = notification->userListElements()[0];
 	text = KaduParser::parse(text, ule);
 
-	OSDWidget *widget = new OSDWidget(0, notification);
-	widgets.append(widget);
-	unsigned int id = widgets.count() - 1;
+	OSDWidget *widget = NULL;
+	widget = findWidget(notification->userListElements());
+	if (widget != NULL)
+	{
+		deleteWidget(widget);
+	}
+	widget = new OSDWidget(0, notification);
+
+	unsigned int id = 0;
+	if (widgets.count() > 0)
+	{
+		id = widgets.last()->getID() + 1;
+	}
+	kdebugm(KDEBUG_INFO, "new widget: %d\n", id);
+	
 	widget->setFont(font);
 	
 	OSDWidget::OSDData data;
@@ -222,7 +233,6 @@ kdebugm(KDEBUG_ERROR, "\n\n\n\n\n\naddOSD\n");
 			def_y = trayPosition.y() - widget->height();
 			corner = 0;
 		}
-		
 		corner = 0;
 	}
 
@@ -288,7 +298,7 @@ kdebugm(KDEBUG_ERROR, "\n\n\n\n\n\naddOSD\n");
 					shift = widget->getHeight() + separator;
 				else
 					shift = widgets.at(id - 1)->getHeight() + separator;
-		
+
 				for (unsigned int iter = 0; iter <= widgets.count() - 2; iter++)
 				{
 					tmp = widgets.at(iter);
@@ -304,8 +314,8 @@ kdebugm(KDEBUG_ERROR, "\n\n\n\n\n\naddOSD\n");
 			break;
 	}
 
-	connect(widget, SIGNAL(timeout(int, bool)), this, SLOT(timeout(int, bool)));
-	connect(widget, SIGNAL(closing(OSDWidget *)), this, SLOT(deleteWidget(OSDWidget *)));
+	connect(widget, SIGNAL(timeout(int, const UserGroup *)), this, SLOT(timeout(int, const UserGroup *)));
+	connect(widget, SIGNAL(closing(OSDWidget *)), this, SLOT(removeWidget(OSDWidget *)));
 
 	connect(widget, SIGNAL(leftButtonClicked(OSDWidget *)), this,
 			  SLOT(leftButtonSlot(OSDWidget *)));
@@ -314,20 +324,20 @@ kdebugm(KDEBUG_ERROR, "\n\n\n\n\n\naddOSD\n");
 	connect(widget, SIGNAL(midButtonClicked(OSDWidget *)), this,
 			  SLOT(midButtonSlot(OSDWidget *)));
 
+	widgets.append(widget);
 	widget->display();
 
 	kdebugf2();
 }
 
-void OSDManager::timeout(int id, bool chat)
+void OSDManager::timeout(int id, const UserGroup *group)
 {
 	kdebugf();
 	kdebugm(KDEBUG_INFO, "timeout: OSDWidget id: %d\n", id);
-	
-	UserListElements users = widgets.at(id)->getUsers();
+
 	int shift = 0;	
 	int iter = 0;
-	OSDWidget *ptr = 0;
+	OSDWidget *ptr = 0, *tmp = 0;
 
 	switch(new_osd)
 	{
@@ -335,12 +345,10 @@ void OSDManager::timeout(int id, bool chat)
 		{
 			int new_id = 0;
 			int count = widgets.count();
-kdebugm(KDEBUG_INFO, "widget count: %d\n", count);
 			while (iter < count)
 			{
 				ptr = widgets.at(iter);
-kdebugm(KDEBUG_INFO, "got widget at pos: %d\n", iter);
-				if (ptr->getID() == id || (chat && ptr->hasUsers() && (ptr->getUsers() == users)))
+				if ((ptr->getID() == id) || (ptr->hasUsers() && group && group->equals(ptr->getUsers())))
 				{
 					if (count > 1)
 					{
@@ -356,9 +364,7 @@ kdebugm(KDEBUG_INFO, "got widget at pos: %d\n", iter);
 						shift = 0;
 						height = 0;
 					}
-kdebugm(KDEBUG_INFO, "remove widget at pos: %d\n", iter);
-					ptr->close();
-					widgets.remove(ptr);
+					deleteWidget(ptr);
 					count--;
 				}
 				else
@@ -370,7 +376,6 @@ kdebugm(KDEBUG_INFO, "remove widget at pos: %d\n", iter);
 					}
 					if (shift != 0)
 					{
-kdebugm(KDEBUG_INFO, "shift widget at pos: %d\n", iter);
 						ptr->setY(ptr->getY() + shift);
 						ptr->setID(new_id);
 						ptr->QWidget::hide();
@@ -386,10 +391,10 @@ kdebugm(KDEBUG_INFO, "shift widget at pos: %d\n", iter);
 		{
 			int new_id = 0;
 			int count = widgets.count();
-			while(iter < count)
+			while (iter < count)
 			{
 				ptr = widgets.at(iter);
-				if (ptr->getID() == id || (chat && ptr->hasUsers() && (ptr->getUsers() == users)))
+				if ((ptr->getID() == id) || (ptr->hasUsers() && group && group->equals(ptr->getUsers())))
 				{
 					if (count > 1)
 					{
@@ -405,8 +410,7 @@ kdebugm(KDEBUG_INFO, "shift widget at pos: %d\n", iter);
 						shift = 0;
 						height = 0;
 					}
-					ptr->close();
-					widgets.remove(ptr);
+					deleteWidget(ptr);
 					count--;
 				}
 				else
@@ -434,18 +438,16 @@ kdebugm(KDEBUG_INFO, "shift widget at pos: %d\n", iter);
 			ptr = widgets.last();
 			do
 			{
-				if (ptr->getID() == id || (chat && ptr->hasUsers() && (ptr->getUsers() == users)))
+				if ((ptr->getID() == id) || (ptr->hasUsers() && group && group->equals(ptr->getUsers())))
 				{
 					shift += ptr->getHeight() + separator;
-					ptr->close();
-					widgets.remove(ptr);
-					
-					if ((uint)(ptr->getID()) == widgets.count())	//TODO: jako tak adniej :)
-					{
-						ptr = widgets.current();
-					}
+					if ((uint)(ptr->getID()) == widgets.count())
+						tmp = widgets.current();
 					else
-						ptr = widgets.prev();
+						tmp = widgets.prev();
+
+					deleteWidget(ptr);
+					ptr = tmp;
 				}
 				else
 				{
@@ -477,19 +479,16 @@ kdebugm(KDEBUG_INFO, "shift widget at pos: %d\n", iter);
 			OSDWidget *ptr = widgets.last();
 			do
 			{
-				if (ptr->getID() == id || (chat && ptr->hasUsers() && (ptr->getUsers() == users)))
+				if ((ptr->getID() == id) || (ptr->hasUsers() && group && group->equals(ptr->getUsers())))
 				{
 					shift += ptr->getHeight() + separator;
-					
-					ptr->close();
-					widgets.remove(ptr);
-					
-					if ((uint)(ptr->getID()) == widgets.count())	//TODO: jako tak adniej :)
-					{
-						ptr = widgets.current();
-					}
+					if ((uint)(ptr->getID()) == widgets.count())
+						tmp = widgets.current();
 					else
-						ptr = widgets.prev();
+						tmp = widgets.prev();
+
+					deleteWidget(ptr);
+					ptr = tmp;
 				}
 				else
 				{
@@ -516,34 +515,56 @@ kdebugm(KDEBUG_INFO, "shift widget at pos: %d\n", iter);
 			break;
 		}
 	}
-
 	kdebugf2();
 }
 
+OSDWidget *OSDManager::findWidget(const UserListElements &users)
+{
+	FOREACH(j, widgets)
+	{
+		if ((*j) && (*j)->hasUsers() && users.equals((*j)->getUsers()))
+		{
+			kdebugm(KDEBUG_INFO, "found widget: %d\n", (*j)->getID());
+			return (*j);
+		}
+	}
+	return NULL;
+}
+
 void OSDManager::deleteAllWidgets(void)
 {
 	kdebugf();
+	kdebugm(KDEBUG_INFO, "deleteAllWidgets\n");
 	
 	height = 0;
+	OSDWidget *tmp;
 
 	CONST_FOREACH(it, widgets)
 	{
-		if (!(*it)->requireManualClosing()) {
-			(*it)->close();
-			(*it)->deleteLater();
-			widgets.remove(*it);
+		tmp = (*it);
+		if (!tmp->requireManualClosing())
+		{
+			deleteWidget(tmp);
 		}
 	}
-	//widgets.clear();
 
 	kdebugf2();
 }
 
 void OSDManager::deleteWidget(OSDWidget *widget)
 {
+	kdebugm(KDEBUG_INFO, "deleteWidget: %d\n", widget->getID());
+
+	widgets.remove(widget);
 	widget->close();
 	widget->deleteLater();
-	widgets.remove(widget);
+	widget = 0;
+}
+
+void OSDManager::removeWidget(OSDWidget *widget)
+{
+	kdebugm(KDEBUG_INFO, "removeWidget: %d\n", widget->getID());
+	timeout(widget->getID(), NULL);
 }
 
 void OSDManager::leftButtonSlot(OSDWidget *widget)
@@ -584,7 +605,6 @@ void OSDManager::processButtonPress(const QString &buttonName, OSDWidget *widget
 		case 1:
 			openChat(widget);
 			widget->acceptNotification();
-
 			deleteWidget(widget);
 			break;
 
@@ -594,7 +614,6 @@ void OSDManager::processButtonPress(const QString &buttonName, OSDWidget *widget
 				chat_manager->deletePendingMsgs(widget->getUsers());
 
 			widget->discardNotification();
-
 			deleteWidget(widget);
 			break;
 
@@ -606,31 +625,6 @@ void OSDManager::processButtonPress(const QString &buttonName, OSDWidget *widget
 	kdebugf2();
 }
 
-void OSDManager::windowActivationChanged(bool b, const UserGroup *users)
-{
-	kdebugf();
-	
-	if (!b)
-	{
-		kdebugm(KDEBUG_INFO, "windowActivated\n");
-		
-		UserListElements u_list = users->toUserListElements();
-		CONST_FOREACH(i, widgets)
-		{
-			if ((*i)->getUsers() == u_list)
-			{
-				timeout((*i)->getID(), true);
-				
-				kdebugf2();
-				return;
-			}
-			
-		}
-	}
-
-	kdebugf2();
-}
-
 void OSDManager::hideToolTip()
 {
 	if (tipWidget)
@@ -675,7 +669,8 @@ void OSDManager::showToolTip(const QPoint &point, const UserListElement &user)
 	data.id = -1;
 	data.translucency_val = translucency_level;
 
-	QPoint pos(kadu->userbox()->mapToGlobal(point) + QPoint(5, 5));
+	QPoint pos(QCursor().pos() + QPoint(5, 5));
+	
 	data.x = pos.x();
 	data.y = pos.y();
 
