@@ -38,7 +38,7 @@ ConfigurationAwareObject
 	
 	public slots:
 		void deleteAllWidgets(void);
-		void deleteWidget(OSDWidget *widget);
+		void removeWidget(OSDWidget *widget);
 		void leftButtonSlot(OSDWidget *widget);
 		void rightButtonSlot(OSDWidget *widget);
 		void midButtonSlot(OSDWidget *widget);
@@ -58,13 +58,14 @@ ConfigurationAwareObject
 		QString defaultSyntax;
 		
 		void addOSD(Notification *notification);
+		void deleteWidget(OSDWidget *widget);
+		OSDWidget *findWidget(const UserListElements &users);
 		void processButtonPress(const QString &buttonName, OSDWidget *widget);
 		void importConfiguration();
 		void setDefaultValues();
 
 	private slots:
-		void timeout(int id, bool chat);
-		void windowActivationChanged(bool, const UserGroup *);
+		void timeout(int id, const UserGroup *group);
 		void chatCreated(ChatWidget *widget);
 		void toolTipClassesHighlighted(const QString &value);
 	
