@@ -11,6 +11,8 @@
 #include "misc.h"
 #include "modules.h"
 #include "debug.h"
+#include "icons_manager.h"
+
 #include "powerkadu.h"
 #include "about_dialog.h"
 
@@ -39,8 +41,14 @@ PowerKadu::PowerKadu()
 {
 	kdebugf();
 
-	separatorPos = kadu->mainMenu()->insertSeparator();
-	pos = kadu->mainMenu()->insertItem(tr("&About PowerKadu..."), this, SLOT(onAboutPowerKadu()));
+	sectionPos = kadu->mainMenu()->count() - 2;
+	separatorPos = kadu->mainMenu()->insertSeparator(sectionPos - 1);
+	pos = kadu->mainMenu()->insertItem(
+			icons_manager->loadIcon(dataPath("kadu/modules/data/powerkadu/powerkadu_32x32.png")),
+			tr("&About PowerKadu..."),
+			this, SLOT(onAboutPowerKadu()),
+			0, -1, sectionPos);
+
 	aboutDialog = 0;
 
 	kdebugf2();
