@@ -320,8 +320,8 @@ E un rischio per la sicurezza!</translation>
         <translation>Indirizzo IP</translation>
     </message>
     <message>
-        <source>You can specify which GG servers to use. Separate every server using semicolon (for example: 217.17.41.82;217.17.41.83;217.17.41.84;217.17.41.144)</source>
-        <translation>Scriva i indirizzi del GG servers di usare. Separare i serveri con punto e virgola (esempio: 217.17.41.82;217.17.41.83;217.17.41.84;217.17.41.144)</translation>
+        <source>You can specify which GG servers to use. Separate every server using semicolon (for example: 91.197.13.26;91.197.13.24;91.197.13.29;91.197.13.6)</source>
+        <translation>Scriva i indirizzi del GG servers di usare. Separare i serveri con punto e virgola (esempio: 91.197.13.26;91.197.13.24;91.197.13.29;91.197.13.6)</translation>
     </message>
     <message>
         <source>Port to connect to servers</source>
@@ -1465,11 +1465,9 @@ Di più conessioni con il password incorretto</translation>
     </message>
     <message>
         <source>Selected users:
-%0
-will be deleted. Are you sure?</source>
+%0will be deleted. Are you sure?</source>
         <translation>Contatti selezionati:
-%0
-saranno eliminati. Vuoi davvero?</translation>
+%0saranno eliminati. Vuoi davvero?</translation>
     </message>
     <message>
         <source>Hide description</source>
@@ -1575,6 +1573,10 @@ saranno eliminati. Vuoi davvero?</translation>
         <source>Me</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Change status</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>KaduTabBar</name>
